@@ -16,6 +16,8 @@ our @EXPORT_OK;
 use XML::LibXML;
 use File::Slurp qw/read_file/;
 
+our $REQUIRE_CHANNEL_ID=1;
+
 my( $dtd, $parser );
 
 =head1 NAME
@@ -192,10 +194,12 @@ sub ValidateFile {
 	$desc = $p->findvalue('desc/text()')
 	    if $p->findvalue( 'count(desc)' );
 
-	if (not defined( $channels{$channelid} )) {
+	my $xmltv_episode = $p->findvalue('episode-num[@system="xmltv_ns"]' );
+
+	if ($REQUIRE_CHANNEL_ID and not exists( $channels{$channelid} )) {
 	    $w->( $p, "Channel '$channelid' does not have a <channel>-entry.",
 		  'unknownid' );
-	    $channels{$channelid} = "auto";
+	    $channels{$channelid} = 0;
 	}
 
 	$channels{$channelid}++;
@@ -212,6 +216,12 @@ sub ValidateFile {
 	$w->( $p, "Invalid stop-time '$stop'", 'badstop' )
 	    if $stop ne "" and not verify_time( $stop );
 
+	if( $xmltv_episode =~ /\S/ ) {
+	    $w->($p, "Invalid episode-number '$xmltv_episode'", 'badepisode' )
+		if $xmltv_episode !~ /^\s*\d*(\/\s*\d+)*\s*\. 
+		                       \s*\d*(\/\s*\d+)*\s*\. 
+		                       \s*\d*(\/\s*\d+)*\s*$/x; 
+	}
     }
 
     foreach my $channel (keys %channels) {
